@@ -4,8 +4,7 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef AKONADICONSOLE_AGENTCONFIGDIALOG_H
-#define AKONADICONSOLE_AGENTCONFIGDIALOG_H
+#pragma once
 
 #include "ui_agentconfigdialog.h"
 #include <AkonadiCore/AgentInstance>
@@ -29,4 +28,3 @@ private:
     Akonadi::AgentInstance m_instance;
 };
 
-#endif
