@@ -6,8 +6,7 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef AKONADICONSOLE_JOBTRACKERWIDGET_H
-#define AKONADICONSOLE_JOBTRACKERWIDGET_H
+#pragma once
 
 #include <QWidget>
 
@@ -37,4 +36,3 @@ private:
     Private *const d;
 };
 
-#endif
