@@ -6,8 +6,7 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef AKONADICONSOLE_MAINWINDOW_H
-#define AKONADICONSOLE_MAINWINDOW_H
+#pragma once
 
 #include "mainwidget.h"
 
@@ -28,4 +27,3 @@ private:
     MainWidget *mMain;
 };
 
-#endif
